aboutsummaryrefslogtreecommitdiff
path: root/main.c
diff options
context:
space:
mode:
Diffstat (limited to 'main.c')
-rw-r--r--main.c3
1 files changed, 2 insertions, 1 deletions
diff --git a/main.c b/main.c
index 55432ab..c8268ee 100644
--- a/main.c
+++ b/main.c
@@ -145,7 +145,8 @@ void tabopen(Cinnamon* cinnamon) {
GtkWidget *webview = webkit_web_view_new();
gtk_notebook_append_page(GTK_NOTEBOOK(cinnamon->notebook), webview, gtk_label_new("New Tab"));
g_signal_connect(webview, "notify::title", G_CALLBACK(on_title_changed), cinnamon->notebook);
- /* HOMEPAGE defined in config.h */
+ /* HOMEPAGE and USERAGENT defined in config.h */
+ webkit_web_view_set_settings(WEBKIT_WEB_VIEW(webview), g_object_new(WEBKIT_TYPE_SETTINGS, "user-agent", USERAGENT, NULL));
webkit_web_view_load_uri(WEBKIT_WEB_VIEW(webview), HOMEPAGE);
gtk_widget_show_all(cinnamon->notebook);
gtk_notebook_set_current_page(GTK_NOTEBOOK(cinnamon->notebook), -1);